ChangeNotifierAdapter class

Drives an Animate animation from a ChangeNotifier. The valueGetter should provide a value in the range 0-1 when a change occurs.

Inheritance
Implementers
Annotations

Constructors

ChangeNotifierAdapter(ChangeNotifier notifier, ValueGetter<double> valueGetter, {bool? animated})
const

Properties

animated → bool
Indicates whether the adapter should animate to new values. If false, it will jump to the new value, if true it will animate to the value using a duration calculated from the animation's total duration and the value change. Defaults to false.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
notifier → ChangeNotifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueGetter → ValueGetter<double>
final

Methods

init(AnimationController controller) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited